==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-powermanagement/lxqt-config-powermanagement/lxqt-config-powermanagement_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Akkumulátor figyelő beállítás</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>Akkumulátor figyelő e&amp;ngedélyezése</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Figyelmeztetés:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> másodperc</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Alacsony energiaszint:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Ikonok a témából:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Előkép</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Töltés</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Kisütés</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Alacsony energiánál:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Ikon mutatás:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>beépített</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Szint: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Tétle&amp;nségi felügyelet</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Tétlenség esetén:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Tétlenségi idő:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> perc</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> másodperc</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Fedé&amp;lfelügyelet</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Teendő fedélzáráskor</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>Akkumulátor</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Semmi</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Készenlét</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Alvás</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>Külső táp</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>&amp;Külső monitor használatakor</translation>
    </message>
    <message>
        <source>On Ac</source>
        <translation type="vanished">Külső táp</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>LXQt Powermanagement Configuration</source>
        <translation type="vanished">LXQt energiafelügyelet beállítás</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation>Energiakezelés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Akkumulátor</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Fedél</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation>Tétlen</translation>
    </message>
    <message>
        <source>idle</source>
        <translation type="vanished">Tétlenség</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Semmi</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Képernyőzár</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Készenlét</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Alvás</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Kikapcsolás</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-powermanagement/lxqt-config-powermanagement/lxqt-config-powermanagement_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Akkumulátor figyelő beállítás</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>Akkumulátor figyelő e&amp;ngedélyezése</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Figyelmeztetés:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> másodperc</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Alacsony energiaszint:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Ikonok a témából:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Előkép</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Töltés</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Kisütés</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Alacsony energiánál:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Ikon mutatás:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>beépített</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Szint: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Tétle&amp;nségi felügyelet</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Tétlenség esetén:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Tétlenségi idő:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> perc</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> másodperc</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Fedé&amp;lfelügyelet</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Teendő fedélzáráskor</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>Akkumulátor</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Semmi</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Készenlét</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Alvás</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>Külső táp</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>&amp;Külső monitor használatakor</translation>
    </message>
    <message>
        <source>On Ac</source>
        <translation type="vanished">Külső táp</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>LXQt Powermanagement Configuration</source>
        <translation type="vanished">LXQt energiafelügyelet beállítás</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation>Energiakezelés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Akkumulátor</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Fedél</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation>Tétlen</translation>
    </message>
    <message>
        <source>idle</source>
        <translation type="vanished">Tétlenség</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Semmi</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Képernyőzár</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Készenlét</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Alvás</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="40"/>
        <source>Turn Off monitor(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
